AdPrivacyConfig class

GroMore SDK 隐私控制。

所有字段都可选。未设置的字段继续使用插件原有默认值,方便旧项目平滑升级。 建议宿主在用户同意隐私政策后,根据实际授权结果显式填写。

Constructors

AdPrivacyConfig({bool? canUseLocation, double? latitude, double? longitude, bool? canUseAppTrackingConsent, String? devOaid, bool? canUsePhoneState, String? imei, bool? canUseWifiState, String? macAddress, bool? canUseWriteExternal, bool? canUseOaid, String? oaid, bool? canUseAndroidId, String? androidId, bool? canUseRecordAudio, bool? canUseMessage, bool? canUseAppList, List<String>? customAppList, List<String>? customDeviceImeis, Map<String, String>? userPrivacyConfig, bool? canUseWifiBssid, String? customIdfa, bool? forbidIdfa, bool? allowUploadDeviceInfo, Map<String, Object?>? iosPrivacyConfig})
const

Properties

allowUploadDeviceInfo bool?
是否允许 GroMore 上传设备信息。仅 iOS。
final
androidId String?
自定义 Android ID。仅 Android。
final
canUseAndroidId bool?
是否允许读取 Android ID。仅 Android。
final
canUseAppList bool?
是否允许读取应用列表。仅 Android。
final
canUseAppTrackingConsent bool?
是否允许 HarmonyOS SDK 使用应用跟踪授权状态。
final
canUseLocation bool?
是否允许读取定位。Android、iOS、HarmonyOS 均支持。
final
canUseMessage bool?
是否允许读取短信相关信息。仅 Android。
final
canUseOaid bool?
是否允许 GroMore 获取 OAID。仅 Android。
final
canUsePhoneState bool?
是否允许读取手机状态。仅 Android。
final
canUseRecordAudio bool?
是否允许使用录音权限。仅 Android。
final
canUseWifiBssid bool?
是否允许读取 Wi-Fi BSSID。仅 iOS。
final
canUseWifiState bool?
是否允许读取 Wi-Fi 状态。Android、HarmonyOS 支持。
final
canUseWriteExternal bool?
是否允许写外部存储。仅 Android。
final
customAppList List<String>?
宿主主动提供的应用包名列表。仅 Android。
final
customDeviceImeis List<String>?
宿主主动提供的设备 IMEI 列表。仅 Android。
final
customIdfa String?
宿主主动提供的 IDFA。仅 iOS。
final
devOaid String?
宿主主动提供给 HarmonyOS SDK 的 OAID。
final
forbidIdfa bool?
是否禁止 SDK 获取 IDFA。仅 iOS。
final
hashCode int
The hash code for this object.
no setterinherited
imei String?
自定义 IMEI。仅 Android。
final
iosPrivacyConfig Map<String, Object?>?
iOS BUAdSDKPrivacyProvider.privacyConfig 透传字段。
final
latitude double?
自定义纬度;必须与 longitude 一起传入。
final
longitude double?
自定义经度;必须与 latitude 一起传入。
final
macAddress String?
自定义 MAC 地址。Android、HarmonyOS 支持。
final
oaid String?
自定义 OAID。仅 Android。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userPrivacyConfig Map<String, String>?
Android GroMore userPrivacyConfig 透传字段。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited