AdEcpmEvent class

广告ECPM事件(千次展示收入)

Inheritance

Constructors

AdEcpmEvent({required String action, required String posId, required int timestamp, required double ecpm, String? networkName, String? adnId, String? channel, String? subChannel, String? requestId, String? ritType, String? scenarioId, String? levelTag, int? biddingType, Map<String, dynamic>? customData, Map<String, dynamic>? extra})
const
AdEcpmEvent.fromMap(Map<String, dynamic> map)
从Map创建ECPM事件对象
factory

Properties

action String
事件动作
finalinherited
adnId String?
广告源ID
final
biddingType int?
final
channel String?
渠道/子渠道
final
customData Map<String, dynamic>?
final
ecpm double
ECPM值
final
extra Map<String, dynamic>?
额外数据
finalinherited
hashCode int
The hash code for this object.
no setterinherited
levelTag String?
final
networkName String?
广告网络名称
final
posId String
广告位ID
finalinherited
requestId String?
请求信息
final
ritType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenarioId String?
final
subChannel String?
final
timestamp int
时间戳
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
转换为Map
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited