SplashAdHarmonyOptions class

HarmonyOS 平台开屏广告可选配置。

Constructors

SplashAdHarmonyOptions({SplashAdFallback? fallback})
const

Properties

fallback SplashAdFallback?
穿山甲直客兜底配置,对应 HarmonyOS CSJSplashUserData
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited