AdLoadInfo class
GroMore 单个 ADN 在本次瀑布流请求中的加载结果。
Constructors
Properties
- adnName → String
-
final
- adType → String
-
final
- customAdnName → String?
-
iOS 自定义 ADN 名称;Android 通常为空。
final
- errorCode → int
-
final
- errorMessage → String
-
final
-
errorUserInfo
→ Map<
String, String> ? -
iOS SDK 返回的补充错误信息。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mediationRit → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited